@@ -27,6 +27,28 @@ class Wimby:
     
     def dump(self):
         if self.movers.count() > 0:
+            print("Wimby Cyrpocurrency Analysis")
+            print("\n[NOTES]")
+            print("A. Do your own research")
+            print("B. Trade at your own risk")
+            print("C. Consult a certified financial expert")
+            print("\n[How to use these data?]")
+            print("1. The ordered list denotes price movements as compared to the 3-day weighted averages.")
+            print("2. Negative percentage means downward movement")
+            print("    * Suggestive to BUY at your discretion")
+            print("3. Positive percentage means upward movement")
+            print("    * Suggestive to SELL at your discretion")
+            print("4. The periodic trend pattern (+/-) denotes the 90, 60, 30, 15, 7, 3, 1-day weighted averages.")
+            print("    * The more negative trends up to the rightmost WAVGs mean successive downward price movement.")
+            print("        - Suggestive to STRONGLY BUY at your discretion")
+            print("    * The more positive trends up to the rightmost WAVGs mean successive upward price movement.")
+            print("        - Suggestive to STRONGLY SELL at your discretion")
+            print("5. Your probable last metric would be on the Coinbase application.")
+            print("    * More than 80% Sell Trend is suggestive to STRONGLY SELL at your discretion.")
+            print("    * More than 60% Sell Trend is suggestive to SELL at your discretion.")
+            print("    * More than 60% Buy Trend is suggestive to HOLD or strategic BUY at your discretion.")
+            print("    * More than 80% Buy Trend is suggestive to HOLD or STRONGLY  BUY at your discretion.")
+            print("6. Use the three (3) metrics to trade or hold strategically.")
             ranking = list(sorted([float(x) for x in self.movers.keys()]))
             minn = len(str(int((min(ranking) * 100)))) + 3
             maxn = len(str(int((max(ranking) * 100)))) + 3
@@ -41,7 +63,7 @@ class Wimby:
                     print(f"{fmovement} {token}")
                     pattern = self.momentum.get(token, {}).get("trend", "")
                     if pattern.strip() != "":
-                        print(f"\t{pattern}")
+                        print(f"    {pattern}")
 
 def _supported(coins, aliases, aliased, debug):
     supported = []
